@@ -148,7 +148,7 @@ find_device_support_ready (MMPluginManager *plugin_manager,
     GError *error = NULL;
 
     if (!mm_plugin_manager_find_device_support_finish (plugin_manager, result, &error)) {
-        mm_warn ("Couldn't find support for device at '%s': %s",
+        mm_info ("Couldn't find support for device at '%s': %s",
                  mm_device_get_path (ctx->device),
                  error->message);
         g_error_free (error);
@@ -270,6 +270,12 @@ device_added (MMBaseManager *manager,
     if (!is_candidate)
         return;
 
+    /* Is the port blacklisted? */
+    if (g_udev_device_get_property_as_boolean (port, "ID_MM_PORT_IGNORE")) {
+        mm_dbg ("(%s/%s): port is blacklisted", subsys, name);
+        return;
+    }
+
     if (find_device_by_port (manager, port))
         return;
 
